@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use Moo;
 
-our $VERSION = '0.01';
+our $VERSION = '0.0101';
 
 use constant K => 3.14159265358979323846 / 180;
 
@@ -202,18 +202,19 @@ Data::Turtle
 
 =head1 VERSION
 
-version 0.01
+version 0.0101
 
 =head1 SYNOPSIS
 
   use Data::Turtle;
-  my $turtle = Turtle->new;
+  my $turtle = Data::Turtle->new;
   $turtle->pen_up;
   $turtle->turn(45);
   $turtle->forward(10);
   $turtle->pen_down;
   for my $i ( 1 .. 4 ) {
-      $turtle->forward(50);
+      my @line = $turtle->forward(50);
+      # If there is a line, draw it...
       $turtle->right(90);
   }
   $turtle->pen_up;
@@ -231,6 +232,9 @@ any particular graphics package.
 The methods don't draw anything per se.  They set or output coordinates and
 values for line drawing by your favorite graphics package.
 
+Please see the F<eg/> distribution directory for example code, with L<GD> and
+L<Imager>.
+
 =head1 NAME
 
 Turtle - Turtle Movement and State Operations
